pub struct AddSubAccountCpiBuilder<'a, 'b> { /* private fields */ }Expand description
Instruction builder for AddSubAccount via CPI.
Accounts:
[writable]main[writable]lst_controller[]admin_permissions[writable, signer]admin[]drift[writable]state[writable]user_stats[writable]user_account[]rent[]system_program
Implementations
Sourceimpl<'a, 'b> AddSubAccountCpiBuilder<'a, 'b>
impl<'a, 'b> AddSubAccountCpiBuilder<'a, 'b>
pub fn new(program: &'b AccountInfo<'a>) -> Self
pub fn main(&mut self, main: &'b AccountInfo<'a>) -> &mut Self
pub fn lst_controller( &mut self, lst_controller: &'b AccountInfo<'a>, ) -> &mut Self
pub fn admin_permissions( &mut self, admin_permissions: &'b AccountInfo<'a>, ) -> &mut Self
pub fn admin(&mut self, admin: &'b AccountInfo<'a>) -> &mut Self
pub fn drift(&mut self, drift: &'b AccountInfo<'a>) -> &mut Self
pub fn state(&mut self, state: &'b AccountInfo<'a>) -> &mut Self
pub fn user_stats(&mut self, user_stats: &'b AccountInfo<'a>) -> &mut Self
pub fn user_account(&mut self, user_account: &'b AccountInfo<'a>) -> &mut Self
pub fn rent(&mut self, rent: &'b AccountInfo<'a>) -> &mut Self
pub fn system_program( &mut self, system_program: &'b AccountInfo<'a>, ) -> &mut Self
Sourcepub fn add_remaining_account(
&mut self,
account: &'b AccountInfo<'a>,
is_writable: bool,
is_signer: bool,
) -> &mut Self
pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self
Add an additional account to the instruction.
Sourcepub fn add_remaining_accounts(
&mut self,
accounts: &[(&'b AccountInfo<'a>, bool, bool)],
) -> &mut Self
pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self
Add additional accounts to the instruction.
Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not,
and a bool indicating whether the account is a signer or not.
pub fn invoke(&self) -> ProgramResult
pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult