pub struct CreateAdminAccountInstructionArgs {
pub new_admin: Pubkey,
pub roles: u8,
}Fields
new_admin: Pubkeyroles: u8Trait Implementations
Sourceimpl BorshDeserialize for CreateAdminAccountInstructionArgs
impl BorshDeserialize for CreateAdminAccountInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CreateAdminAccountInstructionArgs
impl Clone for CreateAdminAccountInstructionArgs
Sourcefn clone(&self) -> CreateAdminAccountInstructionArgs
fn clone(&self) -> CreateAdminAccountInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Eq for CreateAdminAccountInstructionArgs
Sourceimpl PartialEq for CreateAdminAccountInstructionArgs
impl PartialEq for CreateAdminAccountInstructionArgs
Sourcefn eq(&self, other: &CreateAdminAccountInstructionArgs) -> bool
fn eq(&self, other: &CreateAdminAccountInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateAdminAccountInstructionArgs