pub struct FreezeProgramInstructionArgs {
pub freeze: bool,
pub program_index: u8,
}Fields
freeze: boolprogram_index: u8Trait Implementations
Sourceimpl BorshDeserialize for FreezeProgramInstructionArgs
impl BorshDeserialize for FreezeProgramInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for FreezeProgramInstructionArgs
impl Clone for FreezeProgramInstructionArgs
Sourcefn clone(&self) -> FreezeProgramInstructionArgs
fn clone(&self) -> FreezeProgramInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FreezeProgramInstructionArgs
impl Debug for FreezeProgramInstructionArgs
impl Eq for FreezeProgramInstructionArgs
Sourceimpl PartialEq for FreezeProgramInstructionArgs
impl PartialEq for FreezeProgramInstructionArgs
Sourcefn eq(&self, other: &FreezeProgramInstructionArgs) -> bool
fn eq(&self, other: &FreezeProgramInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for FreezeProgramInstructionArgs