pub struct MintStrategy1InstructionArgs {
pub usdc_deposit_amount: u64,
pub min_receipt_receive: u64,
}Fields
usdc_deposit_amount: u64min_receipt_receive: u64Trait Implementations
Sourceimpl BorshDeserialize for MintStrategy1InstructionArgs
impl BorshDeserialize for MintStrategy1InstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for MintStrategy1InstructionArgs
impl Clone for MintStrategy1InstructionArgs
Sourcefn clone(&self) -> MintStrategy1InstructionArgs
fn clone(&self) -> MintStrategy1InstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MintStrategy1InstructionArgs
impl Debug for MintStrategy1InstructionArgs
impl Eq for MintStrategy1InstructionArgs
Sourceimpl PartialEq for MintStrategy1InstructionArgs
impl PartialEq for MintStrategy1InstructionArgs
Sourcefn eq(&self, other: &MintStrategy1InstructionArgs) -> bool
fn eq(&self, other: &MintStrategy1InstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for MintStrategy1InstructionArgs