MintStrategy2CpiBuilder

Struct MintStrategy2CpiBuilder 

pub struct MintStrategy2CpiBuilder<'a, 'b> { /* private fields */ }
Instruction builder for MintStrategy2 via CPI.

Accounts:

  1. [writable, signer] user
  2. [optional] admin_permissions
  3. [writable] main
  4. [writable] strategy_controller
  5. [writable] receipt_mint
  6. [writable] user_receipt_ata
  7. [writable] user_earn_ata
  8. [writable] strategy_controller_earn_token_account
  9. [] token_program
  10. [] associated_token_program
  11. [] instruction_sysvar_account
  12. [] system_program

Implementations

Source

impl<'a, 'b> MintStrategy2CpiBuilder<'a, 'b>

pub fn new(program: &'b AccountInfo<'a>) -> Self

pub fn user(&mut self, user: &'b AccountInfo<'a>) -> &mut Self

pub fn admin_permissions( &mut self, admin_permissions: Option<&'b AccountInfo<'a>>, ) -> &mut Self

[optional account]

pub fn main(&mut self, main: &'b AccountInfo<'a>) -> &mut Self

pub fn strategy_controller( &mut self, strategy_controller: &'b AccountInfo<'a>, ) -> &mut Self

pub fn receipt_mint(&mut self, receipt_mint: &'b AccountInfo<'a>) -> &mut Self

pub fn user_receipt_ata( &mut self, user_receipt_ata: &'b AccountInfo<'a>, ) -> &mut Self

pub fn user_earn_ata(&mut self, user_earn_ata: &'b AccountInfo<'a>) -> &mut Self

pub fn strategy_controller_earn_token_account( &mut self, strategy_controller_earn_token_account: &'b AccountInfo<'a>, ) -> &mut Self

pub fn token_program(&mut self, token_program: &'b AccountInfo<'a>) -> &mut Self

pub fn associated_token_program( &mut self, associated_token_program: &'b AccountInfo<'a>, ) -> &mut Self

pub fn instruction_sysvar_account( &mut self, instruction_sysvar_account: &'b AccountInfo<'a>, ) -> &mut Self

pub fn system_program( &mut self, system_program: &'b AccountInfo<'a>, ) -> &mut Self

pub fn usdt_deposit_amount(&mut self, usdt_deposit_amount: u64) -> &mut Self

pub fn min_receipt_receive(&mut self, min_receipt_receive: u64) -> &mut Self

pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self

Add an additional account to the instruction.

pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self

Add additional accounts to the instruction.

Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not, and a bool indicating whether the account is a signer or not.

pub fn invoke(&self) -> ProgramResult

pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult