pub struct MintStrategy2InstructionArgs {
pub usdt_deposit_amount: u64,
pub min_receipt_receive: u64,
}Fields
usdt_deposit_amount: u64min_receipt_receive: u64Trait Implementations
Sourceimpl BorshDeserialize for MintStrategy2InstructionArgs
impl BorshDeserialize for MintStrategy2InstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for MintStrategy2InstructionArgs
impl Clone for MintStrategy2InstructionArgs
Sourcefn clone(&self) -> MintStrategy2InstructionArgs
fn clone(&self) -> MintStrategy2InstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MintStrategy2InstructionArgs
impl Debug for MintStrategy2InstructionArgs
impl Eq for MintStrategy2InstructionArgs
Sourceimpl PartialEq for MintStrategy2InstructionArgs
impl PartialEq for MintStrategy2InstructionArgs
Sourcefn eq(&self, other: &MintStrategy2InstructionArgs) -> bool
fn eq(&self, other: &MintStrategy2InstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for MintStrategy2InstructionArgs