pub struct RedeemStrategy2InstructionArgs {
pub receipt_burn_amount: u64,
pub min_lst_redeem: u64,
}Fields
receipt_burn_amount: u64min_lst_redeem: u64Trait Implementations
Sourceimpl BorshDeserialize for RedeemStrategy2InstructionArgs
impl BorshDeserialize for RedeemStrategy2InstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for RedeemStrategy2InstructionArgs
impl Clone for RedeemStrategy2InstructionArgs
Sourcefn clone(&self) -> RedeemStrategy2InstructionArgs
fn clone(&self) -> RedeemStrategy2InstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Eq for RedeemStrategy2InstructionArgs
Sourceimpl PartialEq for RedeemStrategy2InstructionArgs
impl PartialEq for RedeemStrategy2InstructionArgs
Sourcefn eq(&self, other: &RedeemStrategy2InstructionArgs) -> bool
fn eq(&self, other: &RedeemStrategy2InstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RedeemStrategy2InstructionArgs