pub struct UpdateActionRoleProtocolInstructionArgs {
pub action: Action,
pub role: Role,
pub update: Update,
}Fields
action: Actionrole: Roleupdate: UpdateTrait Implementations
Sourceimpl BorshDeserialize for UpdateActionRoleProtocolInstructionArgs
impl BorshDeserialize for UpdateActionRoleProtocolInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for UpdateActionRoleProtocolInstructionArgs
impl Clone for UpdateActionRoleProtocolInstructionArgs
Sourcefn clone(&self) -> UpdateActionRoleProtocolInstructionArgs
fn clone(&self) -> UpdateActionRoleProtocolInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Eq for UpdateActionRoleProtocolInstructionArgs
Sourceimpl PartialEq for UpdateActionRoleProtocolInstructionArgs
impl PartialEq for UpdateActionRoleProtocolInstructionArgs
Sourcefn eq(&self, other: &UpdateActionRoleProtocolInstructionArgs) -> bool
fn eq(&self, other: &UpdateActionRoleProtocolInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateActionRoleProtocolInstructionArgs