pub struct UpdateActionRoleStrategyInstructionArgs {
pub action: Action,
pub role: Role,
pub update: Update,
}Fields
action: Actionrole: Roleupdate: UpdateTrait Implementations
Sourceimpl BorshDeserialize for UpdateActionRoleStrategyInstructionArgs
impl BorshDeserialize for UpdateActionRoleStrategyInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for UpdateActionRoleStrategyInstructionArgs
impl Clone for UpdateActionRoleStrategyInstructionArgs
Sourcefn clone(&self) -> UpdateActionRoleStrategyInstructionArgs
fn clone(&self) -> UpdateActionRoleStrategyInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Eq for UpdateActionRoleStrategyInstructionArgs
Sourceimpl PartialEq for UpdateActionRoleStrategyInstructionArgs
impl PartialEq for UpdateActionRoleStrategyInstructionArgs
Sourcefn eq(&self, other: &UpdateActionRoleStrategyInstructionArgs) -> bool
fn eq(&self, other: &UpdateActionRoleStrategyInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateActionRoleStrategyInstructionArgs