pub struct UpdateCapInstructionArgs {
pub new_cap: u64,
}Fields
new_cap: u64Trait Implementations
Sourceimpl BorshDeserialize for UpdateCapInstructionArgs
impl BorshDeserialize for UpdateCapInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for UpdateCapInstructionArgs
impl Clone for UpdateCapInstructionArgs
Sourcefn clone(&self) -> UpdateCapInstructionArgs
fn clone(&self) -> UpdateCapInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateCapInstructionArgs
impl Debug for UpdateCapInstructionArgs
impl Eq for UpdateCapInstructionArgs
Sourceimpl PartialEq for UpdateCapInstructionArgs
impl PartialEq for UpdateCapInstructionArgs
Sourcefn eq(&self, other: &UpdateCapInstructionArgs) -> bool
fn eq(&self, other: &UpdateCapInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateCapInstructionArgs