pub struct UpdateRecipientsInstructionArgs {
pub recipient_addresses: Vec<Pubkey>,
pub recipient_cuts: Vec<u16>,
}Fields
recipient_addresses: Vec<Pubkey>recipient_cuts: Vec<u16>Trait Implementations
Sourceimpl BorshDeserialize for UpdateRecipientsInstructionArgs
impl BorshDeserialize for UpdateRecipientsInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for UpdateRecipientsInstructionArgs
impl Clone for UpdateRecipientsInstructionArgs
Sourcefn clone(&self) -> UpdateRecipientsInstructionArgs
fn clone(&self) -> UpdateRecipientsInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Eq for UpdateRecipientsInstructionArgs
Sourceimpl PartialEq for UpdateRecipientsInstructionArgs
impl PartialEq for UpdateRecipientsInstructionArgs
Sourcefn eq(&self, other: &UpdateRecipientsInstructionArgs) -> bool
fn eq(&self, other: &UpdateRecipientsInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateRecipientsInstructionArgs