pub struct ActionMapping {
pub action: Action,
pub allowed_roles: [Role; 18],
pub role_count: u8,
}Fields
action: Actionallowed_roles: [Role; 18]role_count: u8Trait Implementations
Sourceimpl BorshDeserialize for ActionMapping
impl BorshDeserialize for ActionMapping
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ActionMapping
impl BorshSerialize for ActionMapping
Sourceimpl Clone for ActionMapping
impl Clone for ActionMapping
Sourcefn clone(&self) -> ActionMapping
fn clone(&self) -> ActionMapping
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ActionMapping
impl Debug for ActionMapping
impl Eq for ActionMapping
Sourceimpl PartialEq for ActionMapping
impl PartialEq for ActionMapping
Sourcefn eq(&self, other: &ActionMapping) -> bool
fn eq(&self, other: &ActionMapping) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ActionMapping