pub struct AddedProtocolActionRole {
pub action: Action,
pub role: Role,
}Fields
action: Actionrole: RoleTrait Implementations
Sourceimpl BorshDeserialize for AddedProtocolActionRole
impl BorshDeserialize for AddedProtocolActionRole
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for AddedProtocolActionRole
impl Clone for AddedProtocolActionRole
Sourcefn clone(&self) -> AddedProtocolActionRole
fn clone(&self) -> AddedProtocolActionRole
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AddedProtocolActionRole
impl Debug for AddedProtocolActionRole
impl Eq for AddedProtocolActionRole
Sourceimpl PartialEq for AddedProtocolActionRole
impl PartialEq for AddedProtocolActionRole
Sourcefn eq(&self, other: &AddedProtocolActionRole) -> bool
fn eq(&self, other: &AddedProtocolActionRole) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AddedProtocolActionRole