pub struct AddedStrategyActionRole {
pub action: Action,
pub role: Role,
pub strategy_id: u8,
}Fields
action: Actionrole: Rolestrategy_id: u8Trait Implementations
Sourceimpl BorshDeserialize for AddedStrategyActionRole
impl BorshDeserialize for AddedStrategyActionRole
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for AddedStrategyActionRole
impl Clone for AddedStrategyActionRole
Sourcefn clone(&self) -> AddedStrategyActionRole
fn clone(&self) -> AddedStrategyActionRole
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AddedStrategyActionRole
impl Debug for AddedStrategyActionRole
impl Eq for AddedStrategyActionRole
Sourceimpl PartialEq for AddedStrategyActionRole
impl PartialEq for AddedStrategyActionRole
Sourcefn eq(&self, other: &AddedStrategyActionRole) -> bool
fn eq(&self, other: &AddedStrategyActionRole) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AddedStrategyActionRole