pub struct Attenuation {
pub base_scaling: u32,
pub conditional_scaling: u32,
}Fields
base_scaling: u32conditional_scaling: u32Trait Implementations
Sourceimpl BorshDeserialize for Attenuation
impl BorshDeserialize for Attenuation
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Attenuation
impl BorshSerialize for Attenuation
Sourceimpl Clone for Attenuation
impl Clone for Attenuation
Sourcefn clone(&self) -> Attenuation
fn clone(&self) -> Attenuation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Attenuation
impl Debug for Attenuation
impl Eq for Attenuation
Sourceimpl PartialEq for Attenuation
impl PartialEq for Attenuation
Sourcefn eq(&self, other: &Attenuation) -> bool
fn eq(&self, other: &Attenuation) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for Attenuation