pub struct AttenuationUpdated {
pub deposit: bool,
pub base_scaling: Option<u32>,
pub conditional_scaling: Option<u32>,
pub strategy_id: u8,
}Fields
deposit: boolbase_scaling: Option<u32>conditional_scaling: Option<u32>strategy_id: u8Trait Implementations
Sourceimpl BorshDeserialize for AttenuationUpdated
impl BorshDeserialize for AttenuationUpdated
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for AttenuationUpdated
impl BorshSerialize for AttenuationUpdated
Sourceimpl Clone for AttenuationUpdated
impl Clone for AttenuationUpdated
Sourcefn clone(&self) -> AttenuationUpdated
fn clone(&self) -> AttenuationUpdated
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AttenuationUpdated
impl Debug for AttenuationUpdated
impl Eq for AttenuationUpdated
Sourceimpl PartialEq for AttenuationUpdated
impl PartialEq for AttenuationUpdated
Sourcefn eq(&self, other: &AttenuationUpdated) -> bool
fn eq(&self, other: &AttenuationUpdated) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AttenuationUpdated