pub struct AutoCompound {
pub deposited_vault_value: u64,
pub net_user_flow_since_capture: i64,
pub last_pool_value: u64,
pub queued_recipient_shares: u64,
}Fields
deposited_vault_value: u64net_user_flow_since_capture: i64last_pool_value: u64Trait Implementations
Sourceimpl BorshDeserialize for AutoCompound
impl BorshDeserialize for AutoCompound
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for AutoCompound
impl BorshSerialize for AutoCompound
Sourceimpl Clone for AutoCompound
impl Clone for AutoCompound
Sourcefn clone(&self) -> AutoCompound
fn clone(&self) -> AutoCompound
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AutoCompound
impl Debug for AutoCompound
impl Eq for AutoCompound
Sourceimpl PartialEq for AutoCompound
impl PartialEq for AutoCompound
Sourcefn eq(&self, other: &AutoCompound) -> bool
fn eq(&self, other: &AutoCompound) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AutoCompound