pub struct Base {
pub bump: u8,
pub index: u8,
pub status: Status,
pub mint: Pubkey,
pub cap: u64,
pub access_control: AccessControl,
pub flow: FlowControl,
pub spls: Spls,
pub recipients: Recipients,
pub capture: Capture,
pub reserved: StrategyPadding,
}Fields
bump: u8index: u8status: Statusmint: Pubkeycap: u64access_control: AccessControlflow: FlowControlspls: Splsrecipients: Recipientscapture: Capturereserved: StrategyPaddingTrait Implementations
Sourceimpl BorshDeserialize for Base
impl BorshDeserialize for Base
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Base
impl BorshSerialize for Base
impl Eq for Base
impl StructuralPartialEq for Base