pub struct CapitalConductorComponent {
pub protocols: [YieldVenueAllocation; 8],
pub filled: u8,
pub penalty_scale_factor: u16,
pub max_deviation_bps: u16,
pub min_per_leg_transfer: u64,
pub dust_thresh: u64,
}Fields
protocols: [YieldVenueAllocation; 8]filled: u8penalty_scale_factor: u16max_deviation_bps: u16min_per_leg_transfer: u64dust_thresh: u64Trait Implementations
Sourceimpl BorshDeserialize for CapitalConductorComponent
impl BorshDeserialize for CapitalConductorComponent
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CapitalConductorComponent
impl Clone for CapitalConductorComponent
Sourcefn clone(&self) -> CapitalConductorComponent
fn clone(&self) -> CapitalConductorComponent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CapitalConductorComponent
impl Debug for CapitalConductorComponent
impl Eq for CapitalConductorComponent
Sourceimpl PartialEq for CapitalConductorComponent
impl PartialEq for CapitalConductorComponent
Sourcefn eq(&self, other: &CapitalConductorComponent) -> bool
fn eq(&self, other: &CapitalConductorComponent) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CapitalConductorComponent