pub struct CurrentProtocolBalance {
pub protocol_id: YieldVenue,
pub balance: u64,
}Fields
protocol_id: YieldVenuebalance: u64Trait Implementations
Sourceimpl BorshDeserialize for CurrentProtocolBalance
impl BorshDeserialize for CurrentProtocolBalance
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CurrentProtocolBalance
impl Clone for CurrentProtocolBalance
Sourcefn clone(&self) -> CurrentProtocolBalance
fn clone(&self) -> CurrentProtocolBalance
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CurrentProtocolBalance
impl Debug for CurrentProtocolBalance
impl Eq for CurrentProtocolBalance
Sourceimpl PartialEq for CurrentProtocolBalance
impl PartialEq for CurrentProtocolBalance
Sourcefn eq(&self, other: &CurrentProtocolBalance) -> bool
fn eq(&self, other: &CurrentProtocolBalance) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CurrentProtocolBalance