pub struct CurrentProtocolRatio {
pub protocol_id: YieldVenue,
pub protocol_amount: u64,
pub current_ratio: u16,
pub target_ratio: u16,
}Fields
protocol_id: YieldVenueprotocol_amount: u64current_ratio: u16target_ratio: u16Trait Implementations
Sourceimpl BorshDeserialize for CurrentProtocolRatio
impl BorshDeserialize for CurrentProtocolRatio
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CurrentProtocolRatio
impl Clone for CurrentProtocolRatio
Sourcefn clone(&self) -> CurrentProtocolRatio
fn clone(&self) -> CurrentProtocolRatio
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CurrentProtocolRatio
impl Debug for CurrentProtocolRatio
impl Eq for CurrentProtocolRatio
Sourceimpl PartialEq for CurrentProtocolRatio
impl PartialEq for CurrentProtocolRatio
Sourcefn eq(&self, other: &CurrentProtocolRatio) -> bool
fn eq(&self, other: &CurrentProtocolRatio) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CurrentProtocolRatio