pub struct DriftSpotData {
pub sub_account_id: u16,
pub market_index: u16,
pub base_strategy_spl_index: u8,
}Fields
sub_account_id: u16market_index: u16base_strategy_spl_index: u8Trait Implementations
Sourceimpl BorshDeserialize for DriftSpotData
impl BorshDeserialize for DriftSpotData
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for DriftSpotData
impl BorshSerialize for DriftSpotData
Sourceimpl Clone for DriftSpotData
impl Clone for DriftSpotData
Sourcefn clone(&self) -> DriftSpotData
fn clone(&self) -> DriftSpotData
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DriftSpotData
impl Debug for DriftSpotData
impl Eq for DriftSpotData
Sourceimpl PartialEq for DriftSpotData
impl PartialEq for DriftSpotData
Sourcefn eq(&self, other: &DriftSpotData) -> bool
fn eq(&self, other: &DriftSpotData) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DriftSpotData