pub struct DriftSubAccountsComponent {
pub sub_accounts: SubsVec,
}Fields
sub_accounts: SubsVecTrait Implementations
Sourceimpl BorshDeserialize for DriftSubAccountsComponent
impl BorshDeserialize for DriftSubAccountsComponent
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for DriftSubAccountsComponent
impl Clone for DriftSubAccountsComponent
Sourcefn clone(&self) -> DriftSubAccountsComponent
fn clone(&self) -> DriftSubAccountsComponent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DriftSubAccountsComponent
impl Debug for DriftSubAccountsComponent
impl Eq for DriftSubAccountsComponent
Sourceimpl PartialEq for DriftSubAccountsComponent
impl PartialEq for DriftSubAccountsComponent
Sourcefn eq(&self, other: &DriftSubAccountsComponent) -> bool
fn eq(&self, other: &DriftSubAccountsComponent) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DriftSubAccountsComponent