pub struct DustThresholdUpdated {
pub strategy_idx: u8,
pub old_dust_thresh: u64,
pub new_dust_thresh: u64,
}Fields
strategy_idx: u8old_dust_thresh: u64new_dust_thresh: u64Trait Implementations
Sourceimpl BorshDeserialize for DustThresholdUpdated
impl BorshDeserialize for DustThresholdUpdated
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for DustThresholdUpdated
impl Clone for DustThresholdUpdated
Sourcefn clone(&self) -> DustThresholdUpdated
fn clone(&self) -> DustThresholdUpdated
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DustThresholdUpdated
impl Debug for DustThresholdUpdated
impl Eq for DustThresholdUpdated
Sourceimpl PartialEq for DustThresholdUpdated
impl PartialEq for DustThresholdUpdated
Sourcefn eq(&self, other: &DustThresholdUpdated) -> bool
fn eq(&self, other: &DustThresholdUpdated) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DustThresholdUpdated