pub struct FlowControl {
pub strategy_deposit: Attenuation,
pub strategy_withdraw: Attenuation,
}Fields
strategy_deposit: Attenuationstrategy_withdraw: AttenuationTrait Implementations
Sourceimpl BorshDeserialize for FlowControl
impl BorshDeserialize for FlowControl
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for FlowControl
impl BorshSerialize for FlowControl
Sourceimpl Clone for FlowControl
impl Clone for FlowControl
Sourcefn clone(&self) -> FlowControl
fn clone(&self) -> FlowControl
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FlowControl
impl Debug for FlowControl
impl Eq for FlowControl
Sourceimpl PartialEq for FlowControl
impl PartialEq for FlowControl
Sourcefn eq(&self, other: &FlowControl) -> bool
fn eq(&self, other: &FlowControl) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for FlowControl