pub struct LevelRoles {
pub roles: Vec<Role>,
}Expand description
Handles role management at any hierarchy level (protocol or strategy) with methods for:
- Checking if a specific role exists
- Adding and removing roles
- Checking if the SUPREMO role exists
- Validating if roles can perform specific actions
Fields
roles: Vec<Role>Trait Implementations
Sourceimpl BorshDeserialize for LevelRoles
impl BorshDeserialize for LevelRoles
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for LevelRoles
impl BorshSerialize for LevelRoles
Sourceimpl Clone for LevelRoles
impl Clone for LevelRoles
Sourcefn clone(&self) -> LevelRoles
fn clone(&self) -> LevelRoles
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LevelRoles
impl Debug for LevelRoles
impl Eq for LevelRoles
Sourceimpl PartialEq for LevelRoles
impl PartialEq for LevelRoles
Sourcefn eq(&self, other: &LevelRoles) -> bool
fn eq(&self, other: &LevelRoles) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for LevelRoles