pub struct MaxDeviationBpsUpdated {
pub strategy_idx: u8,
pub old_max_deviation_bps: u16,
pub new_max_deviation_bps: u16,
}Fields
strategy_idx: u8old_max_deviation_bps: u16new_max_deviation_bps: u16Trait Implementations
Sourceimpl BorshDeserialize for MaxDeviationBpsUpdated
impl BorshDeserialize for MaxDeviationBpsUpdated
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for MaxDeviationBpsUpdated
impl Clone for MaxDeviationBpsUpdated
Sourcefn clone(&self) -> MaxDeviationBpsUpdated
fn clone(&self) -> MaxDeviationBpsUpdated
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MaxDeviationBpsUpdated
impl Debug for MaxDeviationBpsUpdated
impl Eq for MaxDeviationBpsUpdated
Sourceimpl PartialEq for MaxDeviationBpsUpdated
impl PartialEq for MaxDeviationBpsUpdated
Sourcefn eq(&self, other: &MaxDeviationBpsUpdated) -> bool
fn eq(&self, other: &MaxDeviationBpsUpdated) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for MaxDeviationBpsUpdated