pub struct MinPerLegTransferUpdated {
pub strategy_idx: u8,
pub old_min_per_leg_transfer: u64,
pub new_min_per_leg_transfer: u64,
}Fields
strategy_idx: u8old_min_per_leg_transfer: u64new_min_per_leg_transfer: u64Trait Implementations
Sourceimpl BorshDeserialize for MinPerLegTransferUpdated
impl BorshDeserialize for MinPerLegTransferUpdated
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for MinPerLegTransferUpdated
impl Clone for MinPerLegTransferUpdated
Sourcefn clone(&self) -> MinPerLegTransferUpdated
fn clone(&self) -> MinPerLegTransferUpdated
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MinPerLegTransferUpdated
impl Debug for MinPerLegTransferUpdated
impl Eq for MinPerLegTransferUpdated
Sourceimpl PartialEq for MinPerLegTransferUpdated
impl PartialEq for MinPerLegTransferUpdated
Sourcefn eq(&self, other: &MinPerLegTransferUpdated) -> bool
fn eq(&self, other: &MinPerLegTransferUpdated) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for MinPerLegTransferUpdated