pub struct PenaltyScaleFactorUpdated {
pub strategy_idx: u8,
pub old_penalty_scale_factor: u16,
pub new_penalty_scale_factor: u16,
}Fields
strategy_idx: u8old_penalty_scale_factor: u16new_penalty_scale_factor: u16Trait Implementations
Sourceimpl BorshDeserialize for PenaltyScaleFactorUpdated
impl BorshDeserialize for PenaltyScaleFactorUpdated
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for PenaltyScaleFactorUpdated
impl Clone for PenaltyScaleFactorUpdated
Sourcefn clone(&self) -> PenaltyScaleFactorUpdated
fn clone(&self) -> PenaltyScaleFactorUpdated
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PenaltyScaleFactorUpdated
impl Debug for PenaltyScaleFactorUpdated
impl Eq for PenaltyScaleFactorUpdated
Sourceimpl PartialEq for PenaltyScaleFactorUpdated
impl PartialEq for PenaltyScaleFactorUpdated
Sourcefn eq(&self, other: &PenaltyScaleFactorUpdated) -> bool
fn eq(&self, other: &PenaltyScaleFactorUpdated) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PenaltyScaleFactorUpdated