pub struct Program {
pub index: u8,
pub id: Pubkey,
pub status: ProgramStatus,
}Fields
index: u8id: Pubkeystatus: ProgramStatusTrait Implementations
Sourceimpl BorshDeserialize for Program
impl BorshDeserialize for Program
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Program
impl BorshSerialize for Program
impl Eq for Program
impl StructuralPartialEq for Program