pub struct ProtocolActionUpdate {
pub action: Action,
pub new_state: bool,
}Fields
action: Actionnew_state: boolTrait Implementations
Sourceimpl BorshDeserialize for ProtocolActionUpdate
impl BorshDeserialize for ProtocolActionUpdate
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for ProtocolActionUpdate
impl Clone for ProtocolActionUpdate
Sourcefn clone(&self) -> ProtocolActionUpdate
fn clone(&self) -> ProtocolActionUpdate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProtocolActionUpdate
impl Debug for ProtocolActionUpdate
impl Eq for ProtocolActionUpdate
Sourceimpl PartialEq for ProtocolActionUpdate
impl PartialEq for ProtocolActionUpdate
Sourcefn eq(&self, other: &ProtocolActionUpdate) -> bool
fn eq(&self, other: &ProtocolActionUpdate) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ProtocolActionUpdate