pub struct ProtocolRatiosUpdated {
pub strategy: u8,
pub old_ratios: Vec<YieldVenueAllocation>,
pub new_ratios: Vec<YieldVenueAllocation>,
}Fields
strategy: u8old_ratios: Vec<YieldVenueAllocation>new_ratios: Vec<YieldVenueAllocation>Trait Implementations
Sourceimpl BorshDeserialize for ProtocolRatiosUpdated
impl BorshDeserialize for ProtocolRatiosUpdated
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for ProtocolRatiosUpdated
impl Clone for ProtocolRatiosUpdated
Sourcefn clone(&self) -> ProtocolRatiosUpdated
fn clone(&self) -> ProtocolRatiosUpdated
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProtocolRatiosUpdated
impl Debug for ProtocolRatiosUpdated
impl Eq for ProtocolRatiosUpdated
Sourceimpl PartialEq for ProtocolRatiosUpdated
impl PartialEq for ProtocolRatiosUpdated
Sourcefn eq(&self, other: &ProtocolRatiosUpdated) -> bool
fn eq(&self, other: &ProtocolRatiosUpdated) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ProtocolRatiosUpdated