pub struct Rack {
pub registry: [Component; 8],
}Fields
registry: [Component; 8]Trait Implementations
Sourceimpl BorshDeserialize for Rack
impl BorshDeserialize for Rack
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Rack
impl BorshSerialize for Rack
impl Eq for Rack
impl StructuralPartialEq for Rack