pub struct Recipient {
pub address: Pubkey,
pub cut: u16,
}Expand description
Cut is in 4 decimal places. Weight of 10.55% is represented as 1055. All weights must add up to 10000.
Fields
address: Pubkeycut: u16Trait Implementations
Sourceimpl BorshDeserialize for Recipient
impl BorshDeserialize for Recipient
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Recipient
impl BorshSerialize for Recipient
impl Eq for Recipient
impl StructuralPartialEq for Recipient