pub struct Recipients {
pub recipients: [Recipient; 10],
pub recipients_count: u8,
}Fields
recipients: [Recipient; 10]recipients_count: u8Trait Implementations
Sourceimpl BorshDeserialize for Recipients
impl BorshDeserialize for Recipients
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Recipients
impl BorshSerialize for Recipients
Sourceimpl Clone for Recipients
impl Clone for Recipients
Sourcefn clone(&self) -> Recipients
fn clone(&self) -> Recipients
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Recipients
impl Debug for Recipients
impl Eq for Recipients
Sourceimpl PartialEq for Recipients
impl PartialEq for Recipients
Sourcefn eq(&self, other: &Recipients) -> bool
fn eq(&self, other: &Recipients) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for Recipients