pub struct RemovedProtocolActionRole {
pub action: Action,
pub role: Role,
}Fields
action: Actionrole: RoleTrait Implementations
Sourceimpl BorshDeserialize for RemovedProtocolActionRole
impl BorshDeserialize for RemovedProtocolActionRole
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for RemovedProtocolActionRole
impl Clone for RemovedProtocolActionRole
Sourcefn clone(&self) -> RemovedProtocolActionRole
fn clone(&self) -> RemovedProtocolActionRole
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemovedProtocolActionRole
impl Debug for RemovedProtocolActionRole
impl Eq for RemovedProtocolActionRole
Sourceimpl PartialEq for RemovedProtocolActionRole
impl PartialEq for RemovedProtocolActionRole
Sourcefn eq(&self, other: &RemovedProtocolActionRole) -> bool
fn eq(&self, other: &RemovedProtocolActionRole) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RemovedProtocolActionRole