pub struct RemovedProtocolRoleHolder {
pub address: Pubkey,
pub role: Role,
}Fields
address: Pubkeyrole: RoleTrait Implementations
Sourceimpl BorshDeserialize for RemovedProtocolRoleHolder
impl BorshDeserialize for RemovedProtocolRoleHolder
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for RemovedProtocolRoleHolder
impl Clone for RemovedProtocolRoleHolder
Sourcefn clone(&self) -> RemovedProtocolRoleHolder
fn clone(&self) -> RemovedProtocolRoleHolder
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemovedProtocolRoleHolder
impl Debug for RemovedProtocolRoleHolder
impl Eq for RemovedProtocolRoleHolder
Sourceimpl PartialEq for RemovedProtocolRoleHolder
impl PartialEq for RemovedProtocolRoleHolder
Sourcefn eq(&self, other: &RemovedProtocolRoleHolder) -> bool
fn eq(&self, other: &RemovedProtocolRoleHolder) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RemovedProtocolRoleHolder