pub struct RemovedStrategyActionRole {
pub action: Action,
pub role: Role,
pub strategy_id: u8,
}Fields
action: Actionrole: Rolestrategy_id: u8Trait Implementations
Sourceimpl BorshDeserialize for RemovedStrategyActionRole
impl BorshDeserialize for RemovedStrategyActionRole
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for RemovedStrategyActionRole
impl Clone for RemovedStrategyActionRole
Sourcefn clone(&self) -> RemovedStrategyActionRole
fn clone(&self) -> RemovedStrategyActionRole
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemovedStrategyActionRole
impl Debug for RemovedStrategyActionRole
impl Eq for RemovedStrategyActionRole
Sourceimpl PartialEq for RemovedStrategyActionRole
impl PartialEq for RemovedStrategyActionRole
Sourcefn eq(&self, other: &RemovedStrategyActionRole) -> bool
fn eq(&self, other: &RemovedStrategyActionRole) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RemovedStrategyActionRole