pub struct Settlement {
pub strategy_id: u8,
pub program: Pubkey,
pub account: Pubkey,
}Fields
strategy_id: u8program: Pubkeyaccount: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for Settlement
impl BorshDeserialize for Settlement
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Settlement
impl BorshSerialize for Settlement
Sourceimpl Clone for Settlement
impl Clone for Settlement
Sourcefn clone(&self) -> Settlement
fn clone(&self) -> Settlement
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Settlement
impl Debug for Settlement
impl Eq for Settlement
Sourceimpl PartialEq for Settlement
impl PartialEq for Settlement
Sourcefn eq(&self, other: &Settlement) -> bool
fn eq(&self, other: &Settlement) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for Settlement