pub struct SplBase {
pub index: u8,
pub spl_main_index: u8,
pub deposits_suspended: bool,
}Fields
index: u8spl_main_index: u8deposits_suspended: boolTrait Implementations
Sourceimpl BorshDeserialize for SplBase
impl BorshDeserialize for SplBase
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SplBase
impl BorshSerialize for SplBase
impl Eq for SplBase
impl StructuralPartialEq for SplBase