pub struct SplMain {
pub main_spl_index: u8,
pub mint: Pubkey,
pub oracle: Pubkey,
pub fee: u64,
pub precision: u8,
pub strategy_indices: Vec<u8>,
pub deposits_suspended: bool,
}Fields
main_spl_index: u8Entry number of this LST. Sequential.
mint: Pubkeyoracle: PubkeyOracle we use for look-up, can be different than the one required by the DEX. TODO: Should be upgradeable
fee: u64In case of variable fees for some type of interacton.
precision: u8Base mint precision of the LST.
strategy_indices: Vec<u8>Array of strategy specific PDAs that support that particular SPL.
deposits_suspended: boolFrozen from minting using it at reflect level.