pub struct SplSupport {
pub mint: Pubkey,
}Fields
mint: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for SplSupport
impl BorshDeserialize for SplSupport
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SplSupport
impl BorshSerialize for SplSupport
Sourceimpl Clone for SplSupport
impl Clone for SplSupport
Sourcefn clone(&self) -> SplSupport
fn clone(&self) -> SplSupport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SplSupport
impl Debug for SplSupport
impl Eq for SplSupport
Sourceimpl PartialEq for SplSupport
impl PartialEq for SplSupport
Sourcefn eq(&self, other: &SplSupport) -> bool
fn eq(&self, other: &SplSupport) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SplSupport