pub struct SplSupportStrategy {
pub mint: Pubkey,
pub strategy_idx: u8,
}Fields
mint: Pubkeystrategy_idx: u8Trait Implementations
Sourceimpl BorshDeserialize for SplSupportStrategy
impl BorshDeserialize for SplSupportStrategy
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SplSupportStrategy
impl BorshSerialize for SplSupportStrategy
Sourceimpl Clone for SplSupportStrategy
impl Clone for SplSupportStrategy
Sourcefn clone(&self) -> SplSupportStrategy
fn clone(&self) -> SplSupportStrategy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SplSupportStrategy
impl Debug for SplSupportStrategy
impl Eq for SplSupportStrategy
Sourceimpl PartialEq for SplSupportStrategy
impl PartialEq for SplSupportStrategy
Sourcefn eq(&self, other: &SplSupportStrategy) -> bool
fn eq(&self, other: &SplSupportStrategy) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SplSupportStrategy