pub struct SplSuspendProtocol {
pub mint: Pubkey,
pub frozen: bool,
}Fields
mint: Pubkeyfrozen: boolTrait Implementations
Sourceimpl BorshDeserialize for SplSuspendProtocol
impl BorshDeserialize for SplSuspendProtocol
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SplSuspendProtocol
impl BorshSerialize for SplSuspendProtocol
Sourceimpl Clone for SplSuspendProtocol
impl Clone for SplSuspendProtocol
Sourcefn clone(&self) -> SplSuspendProtocol
fn clone(&self) -> SplSuspendProtocol
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SplSuspendProtocol
impl Debug for SplSuspendProtocol
impl Eq for SplSuspendProtocol
Sourceimpl PartialEq for SplSuspendProtocol
impl PartialEq for SplSuspendProtocol
Sourcefn eq(&self, other: &SplSuspendProtocol) -> bool
fn eq(&self, other: &SplSuspendProtocol) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SplSuspendProtocol