pub struct SplSuspendStrategy {
pub mint: Pubkey,
pub frozen: bool,
pub strategy_idx: u8,
}Fields
mint: Pubkeyfrozen: boolstrategy_idx: u8Trait Implementations
Sourceimpl BorshDeserialize for SplSuspendStrategy
impl BorshDeserialize for SplSuspendStrategy
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SplSuspendStrategy
impl BorshSerialize for SplSuspendStrategy
Sourceimpl Clone for SplSuspendStrategy
impl Clone for SplSuspendStrategy
Sourcefn clone(&self) -> SplSuspendStrategy
fn clone(&self) -> SplSuspendStrategy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SplSuspendStrategy
impl Debug for SplSuspendStrategy
impl Eq for SplSuspendStrategy
Sourceimpl PartialEq for SplSuspendStrategy
impl PartialEq for SplSuspendStrategy
Sourcefn eq(&self, other: &SplSuspendStrategy) -> bool
fn eq(&self, other: &SplSuspendStrategy) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SplSuspendStrategy