pub struct Spls {
pub spls: [SplBase; 10],
pub spl_count: u8,
}Fields
spls: [SplBase; 10]spl_count: u8Trait Implementations
Sourceimpl BorshDeserialize for Spls
impl BorshDeserialize for Spls
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Spls
impl BorshSerialize for Spls
impl Eq for Spls
impl StructuralPartialEq for Spls