pub struct StrategyActionUpdate {
pub action: Action,
pub new_state: bool,
pub strategy_id: u8,
}Fields
action: Actionnew_state: boolstrategy_id: u8Trait Implementations
Sourceimpl BorshDeserialize for StrategyActionUpdate
impl BorshDeserialize for StrategyActionUpdate
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for StrategyActionUpdate
impl Clone for StrategyActionUpdate
Sourcefn clone(&self) -> StrategyActionUpdate
fn clone(&self) -> StrategyActionUpdate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StrategyActionUpdate
impl Debug for StrategyActionUpdate
impl Eq for StrategyActionUpdate
Sourceimpl PartialEq for StrategyActionUpdate
impl PartialEq for StrategyActionUpdate
Sourcefn eq(&self, other: &StrategyActionUpdate) -> bool
fn eq(&self, other: &StrategyActionUpdate) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for StrategyActionUpdate