pub struct SubsVec {
pub items: [DriftSubs; 4],
pub count: u8,
}Fields
items: [DriftSubs; 4]count: u8Trait Implementations
Sourceimpl BorshDeserialize for SubsVec
impl BorshDeserialize for SubsVec
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SubsVec
impl BorshSerialize for SubsVec
impl Eq for SubsVec
impl StructuralPartialEq for SubsVec