pub struct UpdateCap {
pub old_cap: u64,
pub new_cap: u64,
pub strategy_idx: u8,
}Fields
old_cap: u64new_cap: u64strategy_idx: u8Trait Implementations
Sourceimpl BorshDeserialize for UpdateCap
impl BorshDeserialize for UpdateCap
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateCap
impl BorshSerialize for UpdateCap
impl Eq for UpdateCap
impl StructuralPartialEq for UpdateCap