pub struct UpdateRecipients {
pub old: Vec<Recipient>,
pub new: Vec<Recipient>,
}Fields
old: Vec<Recipient>new: Vec<Recipient>Trait Implementations
Sourceimpl BorshDeserialize for UpdateRecipients
impl BorshDeserialize for UpdateRecipients
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateRecipients
impl BorshSerialize for UpdateRecipients
Sourceimpl Clone for UpdateRecipients
impl Clone for UpdateRecipients
Sourcefn clone(&self) -> UpdateRecipients
fn clone(&self) -> UpdateRecipients
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateRecipients
impl Debug for UpdateRecipients
impl Eq for UpdateRecipients
Sourceimpl PartialEq for UpdateRecipients
impl PartialEq for UpdateRecipients
Sourcefn eq(&self, other: &UpdateRecipients) -> bool
fn eq(&self, other: &UpdateRecipients) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateRecipients