pub struct Main {
pub discriminator: [u8; 8],
pub bump: u8,
pub access_control: AccessControl,
pub lsts_main: Vec<SplMain>,
pub externals: Externals,
pub strategy_counter: u8,
}Fields
discriminator: [u8; 8]bump: u8For rederivation.
access_control: AccessControlPermissions and frozen state.
lsts_main: Vec<SplMain>Master list of all supported SPL that are inputs to the delta-neutral strategies. SPLs that users can use to mint stables (or autocompounds). Stored are:
- mint address
- oracle address (for our use, set to NULL for now)
- fee (unsued)
- precision
- supported DEX indices
externals: ExternalsList of all external programs needed to implement strategies.
strategy_counter: u8Latest PDA derivation seed component for supported dexes.
Implementations